@@ -61,10 +61,12 @@ enum syntaxcode
   Scomment,	/* a comment-starting character */
   Sendcomment,	/* a comment-ending character */
   Sinherit,	/* use the standard syntax table for this character */
+#ifdef SYNTAX_TEXT_PROPERTIES
   Scomment_fence, /* Starts/ends comment which is delimited on the
 		     other side by a char with the same syntaxcode.  */
   Sstring_fence,  /* Starts/ends string which is delimited on the
 		     other side by a char with the same syntaxcode.  */
+#endif /* SYNTAX_TEXT_PROPERTIES */
   Smax	 /* Upper bound on codes that are meaningful */
 };
 
@@ -258,13 +260,18 @@ Lisp_Object syntax_match (Lisp_Object table, Emchar ch);
 
 extern int no_quit_in_re_search;
 extern struct buffer *regex_emacs_buffer;
+#ifndef SYNTAX_TEXT_PROPERTIES
+extern int regex_emacs_buffer_p;
+#else /* SYNTAX_TEXT_PROPERTIES */
 
 /* This is the string or buffer in which we are matching.  It is used
    for looking up syntax properties.  */
 extern Lisp_Object regex_match_object;
+#endif /* SYNTAX_TEXT_PROPERTIES */
 
 void update_syntax_table (Lisp_Char_Table *ct);
 
+#ifdef SYNTAX_TEXT_PROPERTIES
 #ifdef emacs
 
 extern int lookup_syntax_properties;
@@ -473,4 +480,5 @@ void update_syntax_cache (int pos, int count, int init);
        : 0)))
 
 
+#endif /* SYNTAX_TEXT_PROPERTIES */
 #endif /* INCLUDED_syntax_h_ */
